SystemFontManager class

System font manager for loading common system fonts

Constructors

SystemFontManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadSystemFonts({List<String>? preferredFonts, int maxFonts = 5, GraphicsFileSystem? filesystem}) Future<FontFallbackChain>
Load system fonts into a fallback chain (IO-only helper).